@@ -10,11 +10,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.7.0'
-
-# import sip
-# sip.setapi('QString', 2)
-# sip.setapi('QVariant', 2)
+__version__ = '0.7.2'
 
 from PySide.QtGui import QMainWindow, QHBoxLayout, QSizePolicy, QToolButton, \
     QVBoxLayout, QFileDialog, QDesktopServices, QScrollArea, QPushButton, \
@@ -28,11 +24,6 @@ try:
 except:
     pass
 
-try:
-    import osso
-except:
-    pass
-
 from qbadgebutton import QToolBadgeButton
 
 import os
@@ -42,7 +33,7 @@ import logging_config
 from list_view import KhweetsView
 from list_model import KhweetsModel, ISMEROLE, IDROLE, ORIGINROLE, SCREENNAMEROLE, PROTECTEDROLE, USERIDROLE, ISNEWROLE
 from posttweet import post_tweet
-from settings import settings_db, accounts
+from settings import accounts
 
 import dbus
 import dbus.mainloop.glib
@@ -252,8 +243,6 @@ class KhweeteurWin(QMainWindow):
 
         self.setWindowTitle('Khweeteur')
 
-        settings = QSettings()
-
         self.view = KhweetsView()
         self.setCentralWidget(self.view)
 
@@ -262,7 +251,6 @@ class KhweeteurWin(QMainWindow):
         self.view.clicked.connect(self.switch_tb_action)
 
         self.toolbar = QToolBar('Toolbar')
-#        self.toolbar.setMovable(False)
         self.addToolBar(Qt.BottomToolBarArea, self.toolbar)
 
         self.toolbar_mode = 0  # 0 - Default , 1 - Edit, 2 - Action
@@ -822,6 +810,8 @@ class KhweeteurWin(QMainWindow):
             if service is None or service == account['base_url']:
                 accounts_to_consider.append(account)
 
+        target_accounts = accounts_to_consider
+        
         if len(accounts_to_consider) == 1:
             # We have exactly one account that is marked as
             # appropriate for sending tweets.  Use it.
